#import <stdio.h>
#import "vis.h"

int EXPORT_PUBLIC libbar(void) {
  return 0;
}

